.. currentmodule:: netzob

.. _export:

Export
======

Netzob supports the export of the modelization of the protocol in the following formats:
* XML meta representation
* Dedicated Scapy Dissector
* Dedicated Wireshark Dissector

Each export format in described in this chapter.

XML Export
----------

Scapy Dissector
---------------

The Scapy documentation about building new dissectors is available at the following address:

`<http://www.secdev.org/projects/scapy/doc/build_dissect.html>`_


Wireshark Dissector
-------------------

The Wireshark documentation about building new dissectors is available at the following address:

`<http://www.wireshark.org/docs/wsdg_html_chunked/ChDissectAdd.html>`_
